@@ -1,3 +1,4 @@
+import logging
 import smtplib
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
@@ -5,6 +6,8 @@ from urllib.parse import urlparse
 
 import markdown2
 
+logger = logging.getLogger(__name__)
+
 
 def send_markdown_email(auth_url, markdown_content, subject, to_address):
     parsed_url = urlparse(auth_url)
@@ -19,5 +22,9 @@ def send_markdown_email(auth_url, markdown_content, subject, to_address):
     msg.attach(MIMEText(html_content, "html"))
 
     with smtplib.SMTP_SSL(parsed_url.hostname, parsed_url.port) as server:
+        logger.info("Sending email to %s", to_address)
+
         server.login(parsed_url.username, parsed_url.password)
-        server.send_message(msg)
+        result = server.send_message(msg)
+        server.quit()
+        breakpoint()
